@@ -126,7 +126,7 @@ authldap_free_config removed - no longer required.
 static char **l_get_values(LDAP *ld, LDAPMessage *entry, const char *attribut)
 {
 	struct berval **p=ldap_get_values_len(ld, entry, attribut);
-	int n;
+	int i, n;
 	char **a;
 
 	if (!p)
@@ -144,8 +144,6 @@ static char **l_get_values(LDAP *ld, LDAPMessage *entry, const char *attribut)
 		return NULL;
 	}
 
-	int i;
-
 	for (i=0; i<n; i++)
 	{
 		if ((a[i]=malloc(p[i]->bv_len+1)) == NULL)
