@@ -1,5 +1,5 @@
 /*
-** Copyright 1998 - 1999 Double Precision, Inc.  See COPYING for
+** Copyright 1998 - 2008 Double Precision, Inc.  See COPYING for
 ** distribution information.
 */
 
@@ -16,7 +16,7 @@
 #include	"auth.h"
 #include	"courierauthdebug.h"
 
-static const char rcsid[]="$Id: checkpassword.c,v 1.15 2006/10/28 19:22:52 mrsam Exp $";
+static const char rcsid[]="$Id: checkpassword.c,v 1.17 2008/07/10 02:43:55 mrsam Exp $";
 
 #if HAVE_CRYPT
 #if NEED_CRYPT_PROTOTYPE
@@ -24,29 +24,21 @@ extern char *crypt(const char *, const char *);
 #endif
 #endif
 
-#if	HAVE_MD5LIB
 extern int authcheckpasswordmd5(const char *, const char *);
-#endif
-
-#if	HAVE_SHA1LIB
 extern int authcheckpasswordsha1(const char *, const char *);
-#endif
 
 static int do_authcheckpassword(const char *password, const char *encrypted_password)
 {
-#if	HAVE_MD5LIB
 	if (strncmp(encrypted_password, "$1$", 3) == 0
-		|| strncasecmp(encrypted_password, "{MD5}", 5) == 0
-		)
+	    || strncasecmp(encrypted_password, "{MD5}", 5) == 0
+	    || strncasecmp(encrypted_password, "{MD5RAW}", 8) == 0
+	    )
 		return (authcheckpasswordmd5(password, encrypted_password));
-#endif
 
-#if	HAVE_SHA1LIB
 	if (strncasecmp(encrypted_password, "{SHA}", 5) == 0 ||
 	    strncasecmp(encrypted_password, "{SHA256}", 8) == 0
 		)
 		return (authcheckpasswordsha1(password, encrypted_password));
-#endif
 
 #if	HAVE_CRYPT
 	if (strncasecmp(encrypted_password, "{CRYPT}", 7) == 0)
